@@ -72,11 +72,10 @@ def visit_file(file: Path) -> bool:
             return False
         else:
             print(f'Rewriting {str(file)}')
-
-        if contents.endswith('\n') and not new_contents.endswith('\n'):
-            new_contents += '\n'
-        file.write_text(new_contents)
-        return True
+            if contents.endswith('\n') and not new_contents.endswith('\n'):
+                new_contents += '\n'
+            file.write_text(new_contents)
+            return True
 
 
 def visit_paths(files_or_dirs: list[str]) -> int:
@@ -93,10 +92,10 @@ def visit_paths(files_or_dirs: list[str]) -> int:
 
 def main() -> int:
     parser = argparse.ArgumentParser()
-    parser.add_argument('file_or_dir', nargs='*')
+    parser.add_argument('files_or_dirs', nargs='*')
     args = parser.parse_args()
 
-    return visit_paths(args.file_or_dir)
+    return visit_paths(args.files_or_dirs)
 
 
 if __name__ == '__main__':
